pub(crate) fn as_trait_assoc_def<'db>(
db: &dyn HirDatabase,
def: Definition<'db>,
) -> Option<Definition<'db>>Expand description
If this is an trait (impl) assoc item, returns the assoc item of the corresponding trait definition.
pub(crate) fn as_trait_assoc_def<'db>(
db: &dyn HirDatabase,
def: Definition<'db>,
) -> Option<Definition<'db>>If this is an trait (impl) assoc item, returns the assoc item of the corresponding trait definition.